@@ -6,6 +6,8 @@ use strict;
 use warnings;
 use Data::Dump qw(pp);
 
+use Parley::Version;  our $VERSION = $Parley::VERSION;
+
 use DateTime;
 use DateTime::Format::Pg;
 use Text::Context::EitherSide;
@@ -20,7 +22,7 @@ __PACKAGE__->table("post");
 __PACKAGE__->add_columns(
   "id" => {
     data_type => "integer",
-    default_value => "nextval('post_post_id_seq'::regclass)",
+    #default_value => "nextval('post_post_id_seq'::regclass)",
     is_nullable => 0,
     size => 4,
   },
@@ -85,6 +87,9 @@ __PACKAGE__->add_columns(
     is_nullable => 1,
     size => 8,
   },
+
+  admin_editor_id   => {},
+  locked            => {},
 );
 
 __PACKAGE__->set_primary_key("id");
@@ -128,6 +133,10 @@ __PACKAGE__->has_many(
     "people" => "Person",
     { "foreign.last_post" => "self.id" },
 );
+__PACKAGE__->belongs_to(
+    "admin_editor" => "Person",
+    { 'foreign.id' => "self.admin_editor_id" },
+);
 
 
 
