@@ -5,6 +5,8 @@ package Parley::Schema::ThreadView;
 use strict;
 use warnings;
 
+use Parley::Version;  our $VERSION = $Parley::VERSION;
+
 use base 'DBIx::Class';
 use DateTime::Format::Pg;
 
@@ -15,7 +17,7 @@ __PACKAGE__->table("thread_view");
 __PACKAGE__->add_columns(
   "id" => {
     data_type => "integer",
-    default_value => "nextval('thread_view_thread_view_id_seq'::regclass)",
+    #default_value => "nextval('thread_view_thread_view_id_seq'::regclass)",
     is_nullable => 0,
     size => 4,
   },
